summaryrefslogtreecommitdiffstats
path: root/src/include/kernel/cpu.H
diff options
context:
space:
mode:
authorMike Jones <mjjones@us.ibm.com>2011-07-18 13:01:59 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2011-07-19 13:43:56 -0500
commit103f2e58b35ac7218d9960ceb6568ff7ceb332d2 (patch)
treeef4c3bf1e3b8fe380e03d2fc256bdd46d10214fc /src/include/kernel/cpu.H
parentbe301c4ea87c944bd1c51ca2c73ac719cec6b495 (diff)
downloadtalos-hostboot-103f2e58b35ac7218d9960ceb6568ff7ceb332d2.tar.gz
talos-hostboot-103f2e58b35ac7218d9960ceb6568ff7ceb332d2.zip
Shutdown and post status on HostBoot completion
Change-Id: If2ab46af85065b29695a1186ed331fd835944eb4 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/204 Tested-by: Jenkins Server Reviewed-by: Mark W. Wenning <wenning@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/kernel/cpu.H')
-rw-r--r--src/include/kernel/cpu.H24
1 files changed, 15 insertions, 9 deletions
diff --git a/src/include/kernel/cpu.H b/src/include/kernel/cpu.H
index 8f6fedb69..2e2a4b8e4 100644
--- a/src/include/kernel/cpu.H
+++ b/src/include/kernel/cpu.H
@@ -21,21 +21,27 @@ class Scheduler;
*/
struct cpu_t
{
- /** Stack to use while in kernel mode. */
+ /** Stack to use while in kernel mode. */
void* kernel_stack;
- /** ID of the CPU (PIR value) */
+
+ /** ID of the CPU (PIR value) */
cpuid_t cpu;
-
- /** Pointer to the scheduler for this CPU (may not be unique) */
+
+ /** If the CPU is the master */
+ bool master;
+
+ /** Pointer to the scheduler for this CPU (may not be unique) */
Scheduler* scheduler;
- /** Location for scheduler to store per-CPU data, currently used
- * for the local run-queue for processor affinity.
- */
+
+ /** Location for scheduler to store per-CPU data, currently used
+ * for the local run-queue for processor affinity.
+ */
void* scheduler_extra;
- /** Pointer to the idle task for this CPU */
+
+ /** Pointer to the idle task for this CPU */
task_t* idle_task;
- /** XSCOM mutex to serialize access per CPU */
+ /** XSCOM mutex to serialize access per CPU */
mutex_t xscom_mutex;
};
OpenPOWER on IntegriCloud